import { describe, expect, it } from "vitest";
import { getBuild } from "./utils";
import { getClassName } from "../index";

describe.only("babel-tailwind", () => {
  const compileESBuild = getBuild("styleObject");

  it("supports conversion into CSSProperties", async () => {
    const { files } = await compileESBuild({
      clsx: "emotion",
      expectFiles: 1,
      javascript: `
        export function Hello() {
          return (
            <div style={tws\`p-2 text-center\`}>
              Hello, world!
            </div>
          );
        }
    `,
    });

    const clsName = getClassName("p-2 text-center").replace(/^tw-/, "tw_");
    expect(files.js.text).toContain(
      `var ${clsName} = {\n  "padding": "0.5rem",\n  "textAlign": "center"\n}`
    );
    expect(files.js.text).toContain(`style: ${clsName}`);
  });
});
